Index: src/test/graph_test.cc
===================================================================
--- src/test/graph_test.cc	(revision 800)
+++ src/test/graph_test.cc	(revision 826)
@@ -59,6 +59,6 @@
 (skeleton::GraphSkeleton &);
 
-template void checkCompileErasableGraph<skeleton::EraseableGraphSkeleton>
-(skeleton::EraseableGraphSkeleton &);
+template void checkCompileErasableGraph<skeleton::ErasableGraphSkeleton>
+(skeleton::ErasableGraphSkeleton &);
 
 //Compile SmartGraph
Index: src/work/marci/graph_concept.h
===================================================================
--- src/work/marci/graph_concept.h	(revision 652)
+++ src/work/marci/graph_concept.h	(revision 826)
@@ -400,9 +400,9 @@
 
 
-  /// \brief Node-eraseable graph concept.
+  /// \brief Node-erasable graph concept.
   ///
   /// A graph class which provides a function to 
   /// delete any of its nodes.
-  class NodeEraseableGraphConcept : virtual public GraphConcept
+  class NodeErasableGraphConcept : virtual public GraphConcept
   {
   public:
@@ -412,9 +412,9 @@
 
 
-  /// \brief Edge-eraseable graph concept.
+  /// \brief Edge-erasable graph concept.
   /// 
   /// A graph class which provides a function to delete any 
   /// of its edges.
-  class EdgeEraseableGraphConcept : virtual public GraphConcept
+  class EdgeErasableGraphConcept : virtual public GraphConcept
   {
   public:
Index: src/hugo/skeletons/graph.h
===================================================================
--- src/hugo/skeletons/graph.h	(revision 801)
+++ src/hugo/skeletons/graph.h	(revision 826)
@@ -457,13 +457,13 @@
       /// This function deletes all edges and nodes of the graph.
       /// It also frees the memory allocated to store them.
       /// \todo It might belong to \c EraseableGraphSkeleton.
       void clear() { }
     };
 
     /// An empty eraseable graph class.
   
     /// This class is an extension of \c GraphSkeleton. It also makes it
     /// possible to erase edges or nodes.
-    class EraseableGraphSkeleton : public GraphSkeleton
+    class ErasableGraphSkeleton : public GraphSkeleton
     {
     public:
@@ -472,5 +472,5 @@
       /// Defalult constructor.
       ///
-      EraseableGraphSkeleton() { }
+      ErasableGraphSkeleton() { }
       /// Deletes a node.
 
@@ -457,13 +457,13 @@
       /// This function deletes all edges and nodes of the graph.
       /// It also frees the memory allocated to store them.
-      /// \todo It might belong to \c EraseableGraphSkeleton.
+      /// \todo It might belong to \c ErasableGraphSkeleton.
       void clear() { }
     };
@@ -457,13 +457,13 @@
     };
 
-    /// An empty eraseable graph class.
+    /// An empty erasable graph class.
   
     /// This class is an extension of \c GraphSkeleton. It also makes it
Index: src/work/peter/edgepathgraph.h
===================================================================
--- src/work/peter/edgepathgraph.h	(revision 677)
+++ src/work/peter/edgepathgraph.h	(revision 826)
@@ -365,7 +365,7 @@
   };
 
   /// An empty eraseable graph class.
   
   /// This class provides all the common features of an \e eraseable graph
   /// structure,
   /// however completely without implementations and real data structures
@@ -385,5 +385,5 @@
   /// @ref SmartGraph will just refer to this structure.
   template <typename P, typename Gact, typename Gsub>
-  class EraseableEdgePathGraph : public EdgePathGraph<P, Gact, Gsub>
+  class ErasableEdgePathGraph : public EdgePathGraph<P, Gact, Gsub>
   {
   public:
@@ -394,7 +394,7 @@
 
     /// Defalult constructor.
-    EraseableEdgePathGraph() {}
+    ErasableEdgePathGraph() {}
     ///Copy consructor.
-    EraseableEdgePathGraph(const EdgePathGraph<P, Gact, Gsub> &EPG) {}
+    ErasableEdgePathGraph(const EdgePathGraph<P, Gact, Gsub> &EPG) {}
   };
 
@@ -365,7 +365,7 @@
   };
 
-  /// An empty eraseable graph class.
+  /// An empty erasable graph class.
   
@@ -365,7 +365,7 @@
   
-  /// This class provides all the common features of an \e eraseable graph
+  /// This class provides all the common features of an \e erasable graph
   /// structure,
   /// however completely without implementations and real data structures
Index: src/work/peter/hierarchygraph.h
===================================================================
--- src/work/peter/hierarchygraph.h	(revision 691)
+++ src/work/peter/hierarchygraph.h	(revision 826)
@@ -528,7 +528,7 @@
   };
 
-  /// An empty eraseable graph class.
-
-  /// This class provides all the common features of an \e eraseable graph
+  /// An empty erasable graph class.
+
+  /// This class provides all the common features of an \e erasable graph
   /// structure,
   /// however completely without implementations and real data structures
@@ -547,5 +547,5 @@
   /// like @ref ListGraph or
   /// @ref SmartGraph will just refer to this structure.
-template < typename Gact, typename Gsub > class EraseableHierarchyGraph:public HierarchyGraph < Gact,
+template < typename Gact, typename Gsub > class ErasableHierarchyGraph:public HierarchyGraph < Gact,
     Gsub
     >
@@ -564,9 +564,9 @@
 
     /// Defalult constructor.
-    EraseableHierarchyGraph ()
+    ErasableHierarchyGraph ()
     {
     }
     ///Copy consructor.
-    EraseableHierarchyGraph (const HierarchyGraph < Gact, Gsub > &EPG)
+    ErasableHierarchyGraph (const HierarchyGraph < Gact, Gsub > &EPG)
     {
     }
